@@ -1,7 +1,7 @@
 #
-# $Id$
+# $Id: Base.pm,v 3.2 2003/10/28 19:57:56 wpm Exp $
 #
-# (c) 2003-2004 Morgan Stanley and Co.
+# (c) 2003 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -13,13 +13,12 @@ use strict;
 use English;
 use Carp;
 use File::Basename qw(basename);
-use Date::Format;
 
 use IO::File;
 use IO::Pipe;
 
 our $AUTOLOAD	= "";
-our $VERSION = '1.13';
+our $VERSION = '1.2';
 
 our %Carp =
   (
@@ -54,17 +53,12 @@ sub new {
 
     my $self = {};
 
-    foreach my $key ( qw( localtime noauth localauth encrypt quiet timestamps ) ) {
+    foreach my $key ( qw( localtime noauth localauth encrypt quiet ) ) {
 	$self->{$key}++ if $args{$key};
     }
 
     # AFS::Command::VOS -> vos
-    if ( $args{command} ) {
-        my @commands = (split /\s+/,$args{command});
-        push (@{$self->{command}},@commands);
-    } else {
-        @{$self->{command}} = lc((split(/::/,$class))[2]);
-    }
+    $self->{command} = $args{command} || lc((split(/::/,$class))[2]);
 
     bless $self, $class;
 
@@ -147,11 +141,11 @@ sub _operations {
 		  $self->_Croak("Unable to redirect stdout: $ERRNO\n");
 
 		if ( $type eq 'default' ) {
-		    exec @{$self->{command}}, 'help';
+		    exec $self->{command}, 'help';
 		} else {
-		    exec @{$self->{command}}, 'offline', '-help';
+		    exec $self->{command}, 'offline', '-help';
 		}
-		die "Unable to exec @{$self->{command}} help: $ERRNO\n";
+		die "Unable to exec $self->{command} help: $ERRNO\n";
 
 	    } else {
 
@@ -179,7 +173,7 @@ sub _operations {
 	    }
 
 	    if ( $? ) {
-		$self->_Carp("Error running @{$self->{command}} help.  Unable to configure $class");
+		$self->_Carp("Error running $self->{command} help.  Unable to configure $class");
 		return;
 	    }
 
@@ -202,14 +196,12 @@ sub _arguments {
       {
        optional		=> {},
        required		=> {},
-       aliases		=> {},
       };
 
-    my @command;
-    push (@command, @{$self->{command}});
+    my $command = $self->{command};
 
     unless ( $self->_operations($operation) ) {
-	$self->_Carp("Unsupported @command operation '$operation'\n");
+	$self->_Carp("Unsupported $command operation '$operation'\n");
 	return;
     }
 
@@ -236,8 +228,8 @@ sub _arguments {
 	  die "Unable to redirect stderr: $ERRNO\n";
 	STDOUT->fdopen( $pipe->writer()->fileno(), "w" ) ||
 	  die "Unable to redirect stdout: $ERRNO\n";
-	exec @command, $operation, '-help';
-	die "Unable to exec @command help $operation: $ERRNO\n";
+	exec $command, $operation, '-help';
+	die "Unable to exec $command help $operation: $ERRNO\n";
 
     } else {
 
@@ -246,12 +238,12 @@ sub _arguments {
 	while ( <$pipe> ) {
 
 	    if ( /Unrecognized operation '$operation'/ ) {
-		$self->_Carp("Unsupported @command operation '$operation'\n");
+		$self->_Carp("Unsupported $command operation '$operation'\n");
 		$errors++;
 		last;
 	    }
 
-	    next unless s/^Usage:.*\s+$operation\s+//;
+	    next unless s/^Usage:.*$command\s+$operation\s+//;
 
 	    while ( $_ ) {
 		if ( s/^\[\s*-(\w+?)\s*\]\s*//  ) {
@@ -268,7 +260,7 @@ sub _arguments {
 		} elsif ( s/^\s*-(\w+?)\s*// ) {
 		    $arguments->{required}->{$1} = 0;
 		} else {
-		    $self->_Carp("Unable to parse @command help for $operation\n" .
+		    $self->_Carp("Unable to parse $command help for $operation\n" .
 				 "Unrecognized string: '$_'");
 		    $errors++;
 		    last;
@@ -281,31 +273,13 @@ sub _arguments {
 
     }
 
-    #
-    # XXX -- Hack Alert!!!
-    #
-    # Because some asshole decided to change the force option to vos
-    # release from -f to -force, you can't use the API tranparently
-    # with 2 different vos binaries that support the 2 different options.
-    #
-    # If we need more of these, we can add them, as this let's us
-    # alias one argument to another.
-    #
-    if ( $self->isa("AFS::Command::VOS") && $operation eq 'release' ) {
-	if ( exists $arguments->{optional}->{f} ) {
-	    $arguments->{aliases}->{force} = 'f';
-	} elsif ( exists $arguments->{optional}->{force} ) {
-	    $arguments->{aliases}->{f} = 'force';
-	}
-    }
-
     unless ( waitpid($pid,0) ) {
 	$self->_Carp("Unable to get status of child process ($pid)");
 	$errors++;
     }
 
     if ( $? ) {
-	$self->_Carp("Error running @command $operation -help.  Unable to configure @command $operation");
+	$self->_Carp("Error running $command $operation -help.  Unable to configure $command $operation");
 	$errors++;
     }
 
@@ -323,7 +297,7 @@ sub _save_stderr {
 	return;
     };
 
-    my $command = basename((split /\s+/,@{$self->{command}})[0]);
+    my $command = basename($self->{command});
 
     $self->{tmpfile} = "/tmp/.$command.$self->{operation}.$$";
 
@@ -412,12 +386,7 @@ sub _parse_arguments {
 
     } else {
 
-	my @argv = ( @{$self->{command}}, $self->{operation} );
-
-	foreach my $key ( keys %args ) {
-	    next unless $arguments->{aliases}->{$key};
-	    $args{$arguments->{aliases}->{$key}} = delete $args{$key};
-	}
+	my @argv = ( $self->{command}, $self->{operation} );
 
 	foreach my $key ( qw( noauth localauth encrypt ) ) {
 	    next unless $self->{$key};
@@ -444,21 +413,20 @@ sub _parse_arguments {
 		    next unless exists $args{$key};
 		}
 
+		push(@argv,"-$key");
+
 		if ( $hasvalue ) {
 		    if ( ref $args{$key} eq 'HASH' || ref $args{$key} eq 'ARRAY' ) {
 			unless ( ref $hasvalue eq 'ARRAY' ) {
 			    $self->_Carp("Invalid argument '$key': can't provide a list of values");
 			    return;
 			}
-			push(@argv,"-$key");
 			foreach my $value ( ref $args{$key} eq 'HASH' ? %{$args{$key}} : @{$args{$key}} ) {
 			    push(@argv,$value);
 			}
 		    } else {
-			push(@argv,"-$key",$args{$key});
+			push(@argv,$args{$key});
 		    }
-		} else {
-		    push(@argv,"-$key") if $args{$key};
 		}
 
 		delete $args{$key};
@@ -560,7 +528,6 @@ sub _parse_output {
     $self->{errors} = "";
 
     while ( defined($_ = $self->{handle}->getline()) ) {
-	$self->{errors} .= time2str("[%Y-%m-%d %H:%M:%S] ",time,'GMT') if $self->{timestamps};
 	$self->{errors} .= $_;
     }
 
