@@ -1,7 +1,7 @@
 #
-# $Id$
+# $Id: FS.pm,v 3.1 2003/10/08 21:08:21 wpm Exp $
 #
-# (c) 2003-2004 Morgan Stanley and Co.
+# (c) 2003 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -21,7 +21,7 @@ use AFS::Object::Server;
 use AFS::Object::ACL;
 
 our @ISA = qw(AFS::Command::Base);
-our $VERSION = '1.13';
+our $VERSION = '1.2';
 
 sub checkservers {
 
@@ -282,8 +282,8 @@ sub _paths_method {
 		my ($volname,$quota,$used,$percent,$partition) = split;
 
 		$quota = 0 if $quota eq "nolimit";
-		$percent =~ s/\D//g; # want numeric result
-		$partition =~ s/\D//g; # want numeric result
+		$percent =~ s/%//g; # Don't need it -- want numeric result
+		$partition =~ s/%//g; # Don't need it -- want numeric result
 
 		$path->_setAttribute
 		  (
