@@ -1,7 +1,7 @@
 #
-# $Id$
+# $Id: PTS.pm,v 3.1 2003/10/08 21:08:21 wpm Exp $
 #
-# (c) 2003-2004 Morgan Stanley and Co.
+# (c) 2003 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -20,7 +20,7 @@ use AFS::Object::Group;
 use AFS::Object::User;
 
 our @ISA = qw(AFS::Command::Base);
-our $VERSION = '1.13';
+our $VERSION = '1.2';
 
 sub creategroup {
 
@@ -341,7 +341,7 @@ sub membership {
     my $group = undef;
 
     while ( defined($_ = $self->{handle}->getline()) ) {
-
+	
 	if ( /(\S+) \(id: (-?\d+)\)/ ) {
 
 	    $result->_addUser($user) if $user;
@@ -373,9 +373,7 @@ sub membership {
 		$group->_addMembership($1);
 	    }
 
-	} elsif ( /unable to get membership/ ||
-		  /User or group doesn't exist/ ||
-		  /membership list for id \d+ exceeds display limit/ ) {
+	} elsif ( /unable to get membership/ ) {
 
 	    #
 	    # pts still (as of OpenAFS 1.2.8) doesn't have proper exit codes.
