@@ -1,7 +1,7 @@
 #
-# $Id$
+# $Id: ACL.pm,v 3.1 2003/10/08 21:08:22 wpm Exp $
 #
-# (c) 2003-2004 Morgan Stanley and Co.
+# (c) 2003 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -10,7 +10,7 @@ package AFS::Object::ACL;
 use strict;
 
 our @ISA = qw(AFS::Object);
-our $VERSION = '1.13';
+our $VERSION = '1.2';
 
 sub getPrincipals {
     my $self = shift;
@@ -22,7 +22,7 @@ sub getRights {
     my $self = shift;
     my $principal = shift;
     return unless ref $self->{_principals};
-    return $self->{_principals}->{lc($principal)};
+    return $self->{_principals}->{$principal};
 }
 
 sub getEntries {
