@@ -1,7 +1,7 @@
 #
-# $Id$
+# $Id: PTServer.pm,v 3.1 2003/10/08 21:08:24 wpm Exp $
 #
-# (c) 2003-2004 Morgan Stanley and Co.
+# (c) 2003 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -10,7 +10,7 @@ package AFS::Object::PTServer;
 use strict;
 
 our @ISA = qw(AFS::Object);
-our $VERSION = '1.13';
+our $VERSION = '1.2';
 
 sub getGroupNames {
     my $self = shift;
@@ -34,7 +34,7 @@ sub getGroupByName {
     my $self = shift;
     my $name = shift;
     return unless ref $self->{_groups} && ref $self->{_groups}->{_byName};
-    return $self->{_groups}->{_byName}->{lc($name)};
+    return $self->{_groups}->{_byName}->{$name};
 }
 
 sub getGroupById {
@@ -66,7 +66,7 @@ sub getGroup {
 
     if ( exists $args{name} ) {
 	return unless ref $self->{_groups} && ref $self->{_groups}->{_byName};
-	return $self->{_groups}->{_byName}->{lc($args{name})};
+	return $self->{_groups}->{_byName}->{$args{name}};
     }
 
 }
@@ -122,7 +122,7 @@ sub getUserByName {
     my $self = shift;
     my $name = shift;
     return unless ref $self->{_users} && ref $self->{_users}->{_byName};
-    return $self->{_users}->{_byName}->{lc($name)};
+    return $self->{_users}->{_byName}->{$name};
 }
 
 sub getUserById {
@@ -154,7 +154,7 @@ sub getUser {
 
     if ( exists $args{name} ) {
 	return unless ref $self->{_users} && ref $self->{_users}->{_byName};
-	return $self->{_users}->{_byName}->{lc($args{name})};
+	return $self->{_users}->{_byName}->{$args{name}};
     }
 
 }
